#include <stdio.h>
#include <scheduler.h>

/* teams: displays info on just teams, or on given team IDs

   Cameron Kaiser 2021
   BeOS R5
   MAKE BEBOXES GREAT AGAIN
   Public domain. */

void
usage(char *program)
{
	fprintf(stderr, "usage: %s [teamid ...]\n", program);
	exit(1);
}

void
showteaminfo(team_info *t)
{
	fprintf(stdout, "%-10d %-10d %-56s\n",
		t->team, t->thread_count, t->args);
}

void
header()
{
	fprintf(stdout,
" team ID    threads   command\n");
	fprintf(stdout,
"---------- ---------- --------------------------------------------------------\n");
}

int
main(int argc, char **argv)
{
	team_info ti;
	team_id t;
	status_t s;
	int i;
	int e = 0;
	int32 cookie = 0;

	if (argc == 1) {
		header();
		while(get_next_team_info(&cookie, &ti) == B_OK)
			showteaminfo(&ti);
		return 0;
	}

	for(i=1; i<argc; i++) {
		t = atoi(argv[i]);
		if (t < 1) {
			fprintf(stderr, "illegal team ID\n");
			usage(argv[0]);
		}
		s = get_team_info(t, &ti);
		if (s < 0) {
			e = s;
			fprintf(stderr, "no such team: %d\n", t);
			continue;
		}
		if (cookie++ == 0) header();
		showteaminfo(&ti);
	}
	return e;
}
